/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.manager.workflow.plugin;

import org.apache.inlong.manager.common.plugin.Plugin;
import org.apache.inlong.manager.workflow.event.task.QueueOperateListener;
import org.apache.inlong.manager.workflow.event.task.ScheduleOperateListener;
import org.apache.inlong.manager.workflow.event.task.SinkOperateListener;
import org.apache.inlong.manager.workflow.event.task.SortOperateListener;
import org.apache.inlong.manager.workflow.event.task.SourceOperateListener;

import java.util.List;

/**
 * Interface of process plugin.
 */
public interface ProcessPlugin extends Plugin {

    default List<SourceOperateListener> createSourceOperateListeners() {
        return null;
    }

    default List<SinkOperateListener> createSinkOperateListeners() {
        return null;
    }

    default List<ScheduleOperateListener> createScheduleOperateListeners() {
        return null;
    }

    default List<QueueOperateListener> createQueueOperateListeners() {
        return null;
    }

    default List<SortOperateListener> createSortOperateListeners() {
        return null;
    }

}
